#!/usr/bin/env python3

# run from root sources directory: python Scripts/vera++/vera++.py
import os

ignoredEndings = []
ignoredContent = [
    "CMakeFiles",
    "MyGUI_UString",
    "pugixml",
    "sigslot",
    "Wrappers",
    "MyGUI_KeyCode.h:58",
    "InputConverter.h:896",
    "MyGUI_RTTLayer.h:21",
    "HotKeyManager.cpp:44",
    "HotKeyManager.cpp:45",
    "Common/Base/OpenGL/BaseManager.cpp:12",
    "Common/Base/OpenGL/BaseManager.cpp:13",
    "Common/Base/OpenGL3/BaseManager.cpp:12",
    "Common/Base/OpenGL3/BaseManager.cpp:13"
]


def isIgnoredWarning(warning):
    for ignore in ignoredEndings:
        if warning.endswith(ignore):
            return True
    for ignore in ignoredContent:
        if warning.find(ignore) != -1:
            return True
    return False


def parseOutput():
    file = open("temp.vera++", 'r')

    line = file.readline()
    while line != "":
        line = line[0:len(line) - 1]
        if not isIgnoredWarning(line):
            print(line)
        line = file.readline()
    file.close()


def checkDir(folder):
    os.system("vera++ ../../" + folder + " -profile default 2> temp.vera++")
    parseOutput()


os.chdir("Scripts/vera++")
checkDir("*/*/*.h")
checkDir("*/*/*.cpp")
checkDir("*/*/*/*.h")
checkDir("*/*/*/*.cpp")
checkDir("Platforms/*/*/*/*.h")
checkDir("Platforms/*/*/*/*.cpp")
os.chdir("../..")



#!/usr/bin/env python3

import os


def countLines(fileName):
    file = open(fileName, 'r')
    count = 0
    while file.readline() != "":
        count = count + 1
    file.close()
    return count


def CountLinesInFolder(dir_src):
    numLines = 0

    for root, dirs, files in os.walk(dir_src):
        for name in files:
            if name.endswith('.h') or name.endswith('.cpp'):
                f_src = os.path.join(root, name)
                f_src = f_src.replace('\\', '/')
                numLines = numLines + countLines(f_src)

    print(dir_src + " : " + str(numLines))
    return numLines


# ----------

i = 0
i += CountLinesInFolder('../MyGUIEngine')
i += CountLinesInFolder('../Demos')
i += CountLinesInFolder('../Tools')
i += CountLinesInFolder('../UnitTests')
i += CountLinesInFolder('../Common')
i += CountLinesInFolder('../Platforms/OpenGL')
i += CountLinesInFolder('../Platforms/OpenGLES')
i += CountLinesInFolder('../Platforms/OGRE')
i += CountLinesInFolder('../Platforms/DirectX')
i += CountLinesInFolder('../Platforms/DirectX11')
i += CountLinesInFolder('../Platforms/OpenGL3')
i += CountLinesInFolder('../Plugins')
i += CountLinesInFolder('../Wrappers')
print("Total: " + str(i))



#!/usr/bin/env python3

# run from root sources directory: python3 Scripts/cppcheck/cppcheck.py
import os


def checkFolderSources(folder):
    os.system(
        "cppcheck -j 8 --suppressions-list=Scripts/cppcheck/suppressions.txt "
        "--enable=all --std=c++17 --quiet "
        "--project=\"" + folder + "/compile_commands.json\"")


checkFolderSources('cmake-build-debug')
